@@ -12,12 +12,12 @@ def processVideo(input_directory, output_directory, day, hour):
     print("completed processing video...")
 
 # combine all the minutes in an hour
-def getHour(hour_directory):
+def getHour(hour_directory, min = 0, max = 59):
     #print(hour_directory)
     os.chdir(hour_directory)
-    minutes = os.listdir(hour_directory)
+    minutes = os.listdir(hour_directory).sort()
     clips = []
-    for minute in minutes:
+    for minute in minutes[min:max]:
         if minute.endswith(".mp4"):
             try:
                 clips.append(mp.VideoFileClip(minute))
